==> qcad_1.3.3.orig.tar.gz: qcad-1.3.3.orig/ractdraw.h <==
/***************************************************************************
                          ractdraw.h  -  description                              
                             -------------------                                         
    begin                : Wed Apr 28 1999                                           
    copyright            : (C) 1999 by Andreas Mustun                         
    email                : mustun@ribbonsoft.com                                     
 ***************************************************************************/


#ifndef RACTDRAW_H
#define RACTDRAW_H

#include "raction.h"



class RActDraw : public RAction
{
public:

  RActDraw();
  ~RActDraw();

  void serveEvent(int _action,
                  int _myREvent );

  void pointsSingle(int _myREvent);
  void linesNormal(int _myREvent);
  void linesHor(int _myREvent);
  void linesVer(int _myREvent);
  void linesAngle(int _myREvent);
  void linesRect(int _myREvent);
  void linesPara(int _myREvent);
  void linesBisector(int _myREvent);
  void linesTan1(int _myREvent);
  void linesTan2(int _myREvent);
  void linesOrtho(int _myREvent, bool _useAngle=false);

  void arcsCRAA(int _myREvent);
  void arcsPPP(int _myREvent);
  void arcsPara(int _myREvent);

  void circlesCR(int _myREvent);

  void textsNormal(int _myREvent);

  void dimsPara(int _myREvent);
  void dimsHor(int _myREvent);
  void dimsVer(int _myREvent);
  void dimsAngle(int _myREvent);
  void dimsDiam(int _myREvent);
  void dimsRad(int _myREvent);
  void dimsArrow(int _myREvent);

  void hatching(int _myREvent);

};


#endif

// EOF

==> qcad_1.4.7.orig.tar.gz: qcad-1.4.7.orig/ractdraw.h <==
/***************************************************************************
                          ractdraw.h  -  description                              
                             -------------------                                         
    begin                : Wed Apr 28 1999                                           
    copyright            : (C) 1999 by Andreas Mustun                         
    email                : mustun@ribbonsoft.com                                     
 ***************************************************************************/


#ifndef RACTDRAW_H
#define RACTDRAW_H

#include "raction.h"



class RActDraw : public RAction
{
  Q_OBJECT
public:

  RActDraw();
  ~RActDraw();

  void serveEvent(int _action,
                  int _myREvent );

  void pointsSingle(int _myREvent);
  void linesNormal(int _myREvent);
  void linesHor(int _myREvent);
  void linesVer(int _myREvent);
  void linesAngle(int _myREvent);
  void linesRect(int _myREvent);
  void linesPara(int _myREvent);
  void linesBisector(int _myREvent);
  void linesTan1(int _myREvent);
  void linesTan2(int _myREvent);
  void linesOrtho(int _myREvent, bool _useAngle=false);

  void arcsCRAA(int _myREvent);
  void arcsPPP(int _myREvent, bool _circle=false);
  void arcsPara(int _myREvent);

  void circlesCR(int _myREvent);
  void circlesCL(int _myREvent);
  void circles3P(int _myREvent);

  void textsNormal(int _myREvent);

  void dimsPara(int _myREvent);
  void dimsHor(int _myREvent);
  void dimsVer(int _myREvent);
  void dimsAngle(int _myREvent);
  void dimsDiam(int _myREvent);
  void dimsRad(int _myREvent);
  void dimsArrow(int _myREvent);

  void hatching(int _myREvent);

};


#endif

// EOF
